MethodChannelKeyri class

An implementation of KeyriPlatform that uses method channels.

Inheritance

Constructors

MethodChannelKeyri()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

confirmSession(String sessionId, String payload) → Future<bool>
override
denySession(String sessionId, String payload) → Future<bool>
override
easyKeyriAuth(String appKey, String payload, String? publicUserId) → Future<bool?>
override
generateAssociationKey(String publicUserId) → Future<String?>
override
getAssociationKey(String publicUserId) → Future<String?>
override
getUserSignature(String? publicUserId, String customSignedData) → Future<String?>
override
initializeDefaultScreen(String sessionId, String payload) → Future<bool>
override
initiateQrSession(String appKey, String sessionId, String? publicUserId) → Future<Session?>
override
listAssociationKey() → Future<List<String>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited