KeyriPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • KeyriPlatform
Implementers

Constructors

KeyriPlatform()
Constructs a KeyriPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

confirmSession(String sessionId, String payload) → Future<bool>
denySession(String sessionId, String payload) → Future<bool>
easyKeyriAuth(String appKey, String payload, String? publicUserId) → Future<bool?>
generateAssociationKey(String publicUserId) → Future<String?>
getAssociationKey(String publicUserId) → Future<String?>
getUserSignature(String? publicUserId, String customSignedData) → Future<String?>
initializeDefaultScreen(String sessionId, String payload) → Future<bool>
initiateQrSession(String appKey, String sessionId, String? publicUserId) → Future<Session?>
listAssociationKey() → Future<List<String>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ KeyriPlatform
The default instance of KeyriPlatform to use.
getter/setter pair