IPData class

Constructors

IPData(String? continentCode, String? countryCode, String? city, double? latitude, double? longitude, String? regionCode)

Properties

city → String?
final
continentCode → String?
final
countryCode → String?
final
hashCode → int
The hash code for this object.
no setterinherited
latitude → double?
final
longitude → double?
final
regionCode → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic json) → IPData