RiskAnalytics class

Constructors

RiskAnalytics(String? riskStatus, String? riskFlagString, GeoData? geoData)

Properties

geoData → GeoData?
final
hashCode → int
The hash code for this object.
no setterinherited
riskFlagString → String?
final
riskStatus → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic json) → RiskAnalytics